;; Generated package description from poke-mode.el  -*- no-byte-compile: t -*-
(define-package "poke-mode" "0.0.20220409.95403" "Major mode for editing Poke programs" 'nil :commit "caf4d7c02c5eadcff3f8ef5a1009bc8e844e5521" :url "https://elpa.gnu.org/packages/poke-mode.html" :authors '(("Aurelien Aptel" . "aaptel@suse.com")) :maintainer '("Aurelien Aptel" . "aaptel@suse.com"))
